==> convert_hex-0.1.6.tar.gz: lib/convert_hex.dart <==
library convert_hex;
import 'dart:convert';
import 'dart:math';
/// A Calculator.
class Hex {

  static String encode(int dec) {
    int mod = 16;
    int count = dec;
    List<int> hexList = [];
    for (; count > 0;) {
      var ans1 = count / mod;
      var mod1 = ans1.round();
      var ans = count - (mod1 * 16);
      if (ans < 0) {
        mod1 -= 1;
        ans = count - ((mod1) * 16);
      }
      count = mod1;
      hexList.add(ans);
    }
    int length = hexList.length - 1;
    String hex = '';
    for (int i = length; i >= 0; i--) {
      var num = hexList[i];
      if (num < 16) {
        if (num > 9) {
          hex += charEncode(num);
        } else {
          hex += num.toString();
        }
      }
    }

    return hex;
  }

  static int decode(String hex) {
    int value = 0;
    if (hex.length > 0) {
      var array = hex.split('');
      var i = 0;
      for (int count = hex.length - 1; count >= 0; count--) {
        int a = int.tryParse(array[i]) ?? charDecode(array[i]);
        value += (a * pow(16, count));
        i++;
      }
    }
    return value;
  }

  static int charDecode(String hex) {
    switch (hex.toUpperCase()) {
      case 'A':
        return 10;
      case 'B':
        return 11;
      case 'C':
        return 12;
      case 'D':
        return 13;
      case 'E':
        return 14;
      case 'F':
        return 15;
      default:
        return 0;
    }
  }

  static String charEncode(int dec) {
    switch (dec) {
      case 10:
        return 'A';
      case 11:
        return 'B';
      case 12:
        return 'C';
      case 13:
        return 'D';
      case 14:
        return 'E';
      case 15:
        return 'F';
      default:
        return "0";
    }
  }
}
class Hex64 {
  static int decode(String hex) {
    int value = 0;
    if (hex.length > 0) {
      var array = hex.split('');
      var i = 0;
      for (int count = hex.length - 1; count >= 0; count--) {
        //  int a = int.tryParse(array[i]) ?? charDecode(array[i]);
        int a = _base64ToDexAscii(array[i]);
        value += (a * pow(64, count));
        i++;
      }
    }
    return value;
  }

  static int _base64ToDexAscii(String base64){
    var num = -1;
    num =  AsciiCodec().encode(base64)[0];

    if(num >= 48 && num <= 57){
      num += 4;}
    else if(num >= 65 && num <= 90){
      num -= 65;}
    else if(num >= 97 && num <= 122){
      num -= 71;}
    else if(num == 43){num = 62;}
    else if(num == 47){num = 63;}
    return num;
  }

  static StatusEncode encode(int data,int out){
    var value = -1;
    var dataOut = "";
    var outC = out;
    var num = data~/64;
    var succeed = true;
    if((data%64) != 0){
      num++;

    }
    if((outC<num)){
      outC = num;
      succeed = false;
    }
    for(int i=outC; i>0; i--){
      value = (data % pow(64,i))~/(pow(64,i-1));
      dataOut += _asciiTo64(value);
    }

    return StatusEncode(succeed,dataOut);
  }

  static String _asciiTo64(int ascii){
    var num = ascii;

    if(num >= 0 && num <= 25){
      num += 65;}
    else if(num >= 26 && num <= 51){
      num += 71;}
    else if(num >= 52 && num <= 61){
      num -= 4;}
    else if(num == 62){num = 43;}
    else if(num == 63){num = 47;}

    return String.fromCharCode(num);
  }
}

class StatusEncode{
  bool isSucceed;
  String value;
  StatusEncode(this.isSucceed,this.value);
}

==> convert_hex-0.1.7.tar.gz: lib/convert_hex.dart <==
library convert_hex;
import 'dart:convert';
import 'dart:math';
/// A Calculator.
class Hex {

  static String encode(int dec) {
    int mod = 16;
    int count = dec;
    List<int> hexList = [];
    for (; count > 0;) {
      var ans1 = count / mod;
      var mod1 = ans1.round();
      var ans = count - (mod1 * 16);
      if (ans < 0) {
        mod1 -= 1;
        ans = count - ((mod1) * 16);
      }
      count = mod1;
      hexList.add(ans);
    }
    int length = hexList.length - 1;
    String hex = '';
    for (int i = length; i >= 0; i--) {
      var num = hexList[i];
      if (num < 16) {
        if (num > 9) {
          hex += _charEncode(num);
        } else {
          hex += num.toString();
        }
      }
    }

    return hex;
  }

  static int decode(String hex) {
    int value = 0;
    if (hex.length > 0) {
      var array = hex.split('');
      var i = 0;
      for (int count = hex.length - 1; count >= 0; count--) {
        int a = int.tryParse(array[i]) ?? _charDecode(array[i]);
        value += (a * pow(16, count));
        i++;
      }
    }
    return value;
  }

  static int _charDecode(String hex) {
    switch (hex.toUpperCase()) {
      case 'A':
        return 10;
      case 'B':
        return 11;
      case 'C':
        return 12;
      case 'D':
        return 13;
      case 'E':
        return 14;
      case 'F':
        return 15;
      default:
        return 0;
    }
  }

  static String _charEncode(int dec) {
    switch (dec) {
      case 10:
        return 'A';
      case 11:
        return 'B';
      case 12:
        return 'C';
      case 13:
        return 'D';
      case 14:
        return 'E';
      case 15:
        return 'F';
      default:
        return "0";
    }
  }

  static int charDecode(String hex) {
    switch (hex.toUpperCase()) {
      case 'A':
        return 10;
      case 'B':
        return 11;
      case 'C':
        return 12;
      case 'D':
        return 13;
      case 'E':
        return 14;
      case 'F':
        return 15;
      default:
        return int.tryParse(hex);
    }
  }

  static String charEncode(int dec) {
    switch (dec) {
      case 10:
        return 'A';
      case 11:
        return 'B';
      case 12:
        return 'C';
      case 13:
        return 'D';
      case 14:
        return 'E';
      case 15:
        return 'F';
      default:
        if(dec<10&&dec>=0){
          return '$dec';
        }
        return null;
    }
  }
}

class Hex64 {
  static int decode(String hex) {
    int value = 0;
    if (hex.length > 0) {
      var array = hex.split('');
      var i = 0;
      for (int count = hex.length - 1; count >= 0; count--) {
        //  int a = int.tryParse(array[i]) ?? charDecode(array[i]);
        int a = _base64ToDexAscii(array[i]);
        value += (a * pow(64, count));
        i++;
      }
    }
    return value;
  }

  static int _base64ToDexAscii(String base64){
    var num = -1;
    num =  AsciiCodec().encode(base64)[0];

    if(num >= 48 && num <= 57){
      num += 4;}
    else if(num >= 65 && num <= 90){
      num -= 65;}
    else if(num >= 97 && num <= 122){
      num -= 71;}
    else if(num == 43){num = 62;}
    else if(num == 47){num = 63;}
    return num;
  }

  static StatusEncode encode(int data,int out){
    var value = -1;
    var dataOut = "";
    var outC = out;
    var num = data~/64;
    var succeed = true;
    if((data%64) != 0){
      num++;

    }
    if((outC<num)){
      outC = num;
      succeed = false;
    }
    for(int i=outC; i>0; i--){
      value = (data % pow(64,i))~/(pow(64,i-1));
      dataOut += _asciiTo64(value);
    }

    return StatusEncode(succeed,dataOut);
  }

  static String _asciiTo64(int ascii){
    var num = ascii;

    if(num >= 0 && num <= 25){
      num += 65;}
    else if(num >= 26 && num <= 51){
      num += 71;}
    else if(num >= 52 && num <= 61){
      num -= 4;}
    else if(num == 62){num = 43;}
    else if(num == 63){num = 47;}

    return String.fromCharCode(num);
  }
}

class StatusEncode{
  bool isSucceed;
  String value;
  StatusEncode(this.isSucceed,this.value);
}
